import { hash } from "ohash";
import { ssrRenderSlotInner } from "vue/server-renderer";
export function getCacheKey(props, vnode) {
  const componentName = getComponentName(vnode);
  const hasProps = Object.keys(vnode.props || {}).length > 0;
  const cacheKeyBase = props.cacheKey || (hasProps ? hash(vnode.props) : "");
  if (!componentName) {
    console.debug("Skipped caching component because component has no name.");
    return;
  }
  if (cacheKeyBase) {
    return `${componentName}::${cacheKeyBase}`;
  }
  return componentName;
}
export function getComponentName(vnode) {
  if (typeof vnode.type === "object") {
    if ("__name" in vnode.type) {
      return vnode.type.__name;
    } else if ("name" in vnode.type) {
      return vnode.type.name;
    }
  }
}
function isPromise(p) {
  if (typeof p === "object" && typeof p.then === "function") {
    return true;
  }
  return false;
}
async function unrollBuffer(buffer) {
  let ret = "";
  for (let i = 0; i < buffer.length; i++) {
    let item = buffer[i];
    if (isPromise(item)) {
      item = await item;
    }
    if (typeof item === "string") {
      ret += item;
    } else {
      ret += await unrollBuffer(item);
    }
  }
  return ret;
}
export function renderSlot(slots, parent) {
  const buffer = [];
  const push = (v) => {
    buffer.push(v);
  };
  ssrRenderSlotInner(
    slots,
    "default",
    {},
    null,
    push,
    parent
  );
  return unrollBuffer(buffer);
}
export async function getCachedComponent(storage, cacheKey) {
  const cached = await storage.getItem(
    cacheKey
  );
  if (cached) {
    if (typeof cached === "object") {
      return cached;
    } else if (typeof cached === "string") {
      return {
        data: cached
      };
    }
  }
}
