import { useSSRContext } from "vue";
import {
  getExpiresValue,
  getMultiCacheContext,
  isExpired
} from "./../helpers/server";
export function useDataCache(key, providedEvent) {
  const dummy = {
    addToCache: (v) => {
      return Promise.resolve();
    },
    cacheTags: []
  };
  if (process.client) {
    return Promise.resolve(dummy);
  }
  try {
    const event = (() => {
      if (providedEvent) {
        return providedEvent;
      }
      const ssrContext = useSSRContext();
      if (ssrContext) {
        return ssrContext.event;
      }
    })();
    const multiCache = getMultiCacheContext(event);
    if (!multiCache?.data) {
      return Promise.resolve(dummy);
    }
    return multiCache.data.getItem(key).then((v) => {
      const item = v;
      const addToCache = (data, cacheTags = [], maxAge) => {
        const item2 = { data, cacheTags };
        if (maxAge) {
          item2.expires = getExpiresValue(maxAge);
        }
        return multiCache.data.setItem(key, item2);
      };
      if (item && !isExpired(item)) {
        return {
          addToCache,
          value: item.data,
          cacheTags: item.cacheTags || [],
          expires: item.expires
        };
      }
      return {
        addToCache,
        cacheTags: []
      };
    });
  } catch (e) {
    if (e instanceof Error) {
      console.debug(e.message);
    }
  }
  return Promise.resolve(dummy);
}
