export declare class NuxtMultiCacheRouteCacheHelper {
    /**
     * The collected cache tags.
     */
    tags: string[];
    /**
     * Indicates if the route should be cacheable.
     */
    cacheable: boolean | null;
    /**
     * The maximum age.
     */
    maxAge: number | null;
    constructor();
    /**
     * Add cache tags for this route.
     */
    addTags(tags?: string[]): NuxtMultiCacheRouteCacheHelper;
    /**
     * Mark this route as cacheable.
     *
     * The initial value is null and this method only changes the value if it is
     * null. This means that once it's set to uncacheable, there is no way to
     * change it back.
     */
    setCacheable(): NuxtMultiCacheRouteCacheHelper;
    /**
     * Mark the route as uncacheable.
     *
     * After that there is no way to make it cacheable again.
     */
    setUncacheable(): NuxtMultiCacheRouteCacheHelper;
    /**
     * Set the max age in seconds.
     *
     * The value is only set if it's smaller than the current max age or if it
     * hasn't been set yet. The initial value is `null`.
     *
     * You can always directly set the maxAge property on this object.
     */
    setMaxAge(maxAge?: number): NuxtMultiCacheRouteCacheHelper;
}
