import { createError, getHeader } from "h3";
import { getModuleConfig } from "./../../helpers/index.mjs";
import { getMultiCacheContext } from "./../../../helpers/server.mjs";
const AUTH_HEADER = "x-nuxt-multi-cache-token";
export function getCacheInstance(event) {
  const cacheContext = getMultiCacheContext(event);
  if (!cacheContext) {
    throw createError({
      statusCode: 500,
      statusMessage: "Failed to load cache context."
    });
  }
  const cacheName = event.context.params.cacheName;
  const cache = cacheContext[cacheName];
  if (!cache) {
    throw createError({
      statusCode: 404,
      statusMessage: `The given cache "${cacheName}" is not available.`
    });
  }
  return cache;
}
export async function checkAuth(event, providedModuleConfig) {
  const moduleConfig = providedModuleConfig || await getModuleConfig();
  const authorization = moduleConfig?.api?.authorization;
  if (authorization === false) {
    return;
  } else if (typeof authorization === "function") {
    const result = await authorization(event);
    if (result) {
      return;
    }
  } else if (typeof authorization === "string") {
    const headerToken = getHeader(event, AUTH_HEADER);
    if (headerToken === authorization) {
      return;
    }
  } else {
    throw createError({
      statusCode: 500,
      statusMessage: "No authorization configuration option provided."
    });
  }
  throw createError({
    statusCode: 401,
    statusMessage: "Unauthorized"
  });
}
