import type { NuxtMultiCacheSSRContext } from './../../types';
/**
 * A helper class to debounce cache tag invalidation.
 *
 * This prevents having too many invalidation requests coming in at once that
 * could lead to performance issues since tag invalidation is very
 * inefficient.
 */
export declare class DebouncedInvalidator {
    /**
     * Buffer of tags to invalidate in the next run.
     */
    tags: string[];
    /**
     * Debounce delay.
     */
    delay: number | undefined;
    /**
     * The current timeout ID for the next run. Reset after each run.
     */
    timeout: any;
    /**
     * The cache context instance.
     */
    cacheContext: NuxtMultiCacheSSRContext | undefined;
    constructor();
    setDelay(delay?: number): void;
    /**
     * Add tags to be purged.
     */
    add(tags?: string[]): void;
    /**
     * Invalidate the tags in the buffer.
     */
    invalidate(): Promise<true | undefined>;
}
/**
 * Purges all cache entries by tag.
 *
 * Currently this is highliy inefficient, since we have to load each cache
 * entry in order to figure out if it has to be invalidated.
 *
 * Should be refactored so that a separate lookup table is managed that keeps
 * track of all cache tags and the cache items that use them.
 */
declare const _default: import("h3").EventHandler<{
    status: string;
    tags: string[];
}>;
export default _default;
