import { defineEventHandler } from "h3";
import { format } from "@tusbar/cache-control";
import {
  getMultiCacheCDNHelper,
  getMultiCacheContext,
  getMultiCacheRouteHelper
} from "./../helpers/server";
export default defineEventHandler((event) => {
  const cdnHelper = getMultiCacheCDNHelper(event);
  const multiCache = getMultiCacheContext(event);
  if (!cdnHelper && !multiCache?.route) {
    return;
  }
  const response = event.node.res;
  const _end = response.end;
  response.end = function(arg1, arg2, arg3) {
    if (typeof arg1 === "function") {
      return _end.call(event.node.res, arg1);
    }
    const chunk = arg1;
    if (cdnHelper) {
      const runtimeConfig = useRuntimeConfig();
      const cacheTagsValue = cdnHelper._tags.join(" ");
      if (cacheTagsValue) {
        response.setHeader(
          runtimeConfig.multiCache.cdn.cacheTagHeader,
          cacheTagsValue
        );
      }
      const cacheControlValue = format(cdnHelper._control);
      if (cacheControlValue) {
        response.setHeader(
          runtimeConfig.multiCache.cdn.cacheControlHeader,
          cacheControlValue
        );
      }
    }
    if (event.path) {
      const routeHelper = getMultiCacheRouteHelper(event);
      if (routeHelper && routeHelper.cacheable) {
        const multiCache2 = getMultiCacheContext(event);
        if (multiCache2?.route && event.path) {
          const response2 = event.node.res;
          const headers = response2.getHeaders();
          const item = {
            data: chunk,
            headers,
            statusCode: response2.statusCode
          };
          if (routeHelper.maxAge) {
            item.expires = Math.round(Date.now() / 1e3) + routeHelper.maxAge;
          }
          if (routeHelper.tags.length) {
            item.cacheTags = routeHelper.tags;
          }
          multiCache2.route.setItem(event.path, item);
        }
      }
    }
    return _end.call(event.node.res, arg1, arg2, arg3);
  };
});
