import { defineEventHandler, setResponseHeaders } from "h3";
import { getMultiCacheContext } from "./../helpers/server.mjs";
export default defineEventHandler(async (event) => {
  if (!event.path) {
    return;
  }
  const multiCache = getMultiCacheContext(event);
  if (!multiCache?.route) {
    return;
  }
  try {
    const cached = await multiCache.route.getItem(event.path);
    if (cached && typeof cached === "object") {
      const { data, headers, statusCode, expires } = cached;
      if (expires) {
        const now = Date.now() / 1e3;
        if (now >= expires) {
          return;
        }
      }
      if (headers) {
        setResponseHeaders(event, headers);
      }
      if (statusCode) {
        event.node.res.statusCode = statusCode;
      }
      return data;
    }
  } catch (e) {
    if (e instanceof Error) {
      console.debug(e.message);
    }
  }
});
